==> google-cloud-essential-contacts-0.4.1.tar.gz: google-cloud-essential-contacts-0.4.1/google/cloud/essential_contacts/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.essential_contacts_v1.services.essential_contacts_service.client import (
    EssentialContactsServiceClient,
)
from google.cloud.essential_contacts_v1.services.essential_contacts_service.async_client import (
    EssentialContactsServiceAsyncClient,
)

from google.cloud.essential_contacts_v1.types.enums import NotificationCategory
from google.cloud.essential_contacts_v1.types.enums import ValidationState
from google.cloud.essential_contacts_v1.types.service import ComputeContactsRequest
from google.cloud.essential_contacts_v1.types.service import ComputeContactsResponse
from google.cloud.essential_contacts_v1.types.service import Contact
from google.cloud.essential_contacts_v1.types.service import CreateContactRequest
from google.cloud.essential_contacts_v1.types.service import DeleteContactRequest
from google.cloud.essential_contacts_v1.types.service import GetContactRequest
from google.cloud.essential_contacts_v1.types.service import ListContactsRequest
from google.cloud.essential_contacts_v1.types.service import ListContactsResponse
from google.cloud.essential_contacts_v1.types.service import SendTestMessageRequest
from google.cloud.essential_contacts_v1.types.service import UpdateContactRequest

__all__ = (
    "EssentialContactsServiceClient",
    "EssentialContactsServiceAsyncClient",
    "NotificationCategory",
    "ValidationState",
    "ComputeContactsRequest",
    "ComputeContactsResponse",
    "Contact",
    "CreateContactRequest",
    "DeleteContactRequest",
    "GetContactRequest",
    "ListContactsRequest",
    "ListContactsResponse",
    "SendTestMessageRequest",
    "UpdateContactRequest",
)

==> google-cloud-essential-contacts-1.3.0.tar.gz: google-cloud-essential-contacts-1.3.0/google/cloud/essential_contacts/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.essential_contacts import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.essential_contacts_v1.services.essential_contacts_service.async_client import (
    EssentialContactsServiceAsyncClient,
)
from google.cloud.essential_contacts_v1.services.essential_contacts_service.client import (
    EssentialContactsServiceClient,
)
from google.cloud.essential_contacts_v1.types.enums import (
    NotificationCategory,
    ValidationState,
)
from google.cloud.essential_contacts_v1.types.service import (
    ComputeContactsRequest,
    ComputeContactsResponse,
    Contact,
    CreateContactRequest,
    DeleteContactRequest,
    GetContactRequest,
    ListContactsRequest,
    ListContactsResponse,
    SendTestMessageRequest,
    UpdateContactRequest,
)

__all__ = (
    "EssentialContactsServiceClient",
    "EssentialContactsServiceAsyncClient",
    "NotificationCategory",
    "ValidationState",
    "ComputeContactsRequest",
    "ComputeContactsResponse",
    "Contact",
    "CreateContactRequest",
    "DeleteContactRequest",
    "GetContactRequest",
    "ListContactsRequest",
    "ListContactsResponse",
    "SendTestMessageRequest",
    "UpdateContactRequest",
)
